!----------------------------------------------------------------------
 
! Code converted using TO_F90 by Alan Miller
! Date: 2000-07-11  Time: 12:08:44

! 3. EX1.FOR, EXAMPLE 1

! This example is fully described in the paper. The description is
! repeated here.  The problem is a small artificial one (called the
! New Brunswick problem) in which it is wanted to obtain estimates
! for the elements of the parameter vector ~ in the following three
! functional equations which apply for all i=1,2,...,6

!             (see published paper)

! The parameters which describe the magnitude of the problem are:
!     the number of data vectors, NDAT=6
!     the number of equations, NEQ=3
!     the number of model parameters to be estimated, NPAR=4
!     the number of measured variables in a data vector, NVAR=5.
! The program parameters CRIT1 and CRIT2 were both set at 1.E-6 while NITER1
! and NITER2 were 50 and 20.  The full Fortran code as used is listed in
! EX1.FOR.  The data in the form required for input to the program are given
! in the file EX1.DAT.  The same data are listed with descriptive headings at
! the beginning of the file EX1.OUT.  The latter part of EX1.OUT shows the
! output from the program.

! EX1.FOR

!  TEST PROGRAM FOR EVM USING NEW BRUNSWICK PROBLEM   91/3/27 PMR

PROGRAM ex1
USE Errors_in_Variables
IMPLICIT NONE

REAL (dp)  :: b(3,5), DATA(6,5), est(6,5), g1(4,4), phi,  &
              g3(4,4), q1(4), resid(6,5), theta(4), v(5,5)
INTEGER    :: i, ifault(2), j

OPEN(20, FILE='ex1.dat', STATUS='OLD')
OPEN(30, FILE='ex1.res')
READ (20,*) theta
READ (20,*) ((DATA(i,j),j=1,5),i=1,6)
READ (20,*) v
WRITE (30,10)
10 FORMAT (t37, 'TABLE 1')
WRITE (30,20)
20 FORMAT (//'DATA')
WRITE (30,30) ((DATA(i,j),j=1,5),i=1,6)
30 FORMAT (5F9.2)
WRITE (30,40)
40 FORMAT (//'V')
WRITE (30,30) v
WRITE (30,50) theta
50 FORMAT (//'INITIAL PARAMETER ESTIMATES = ', 4F9.2)
CALL evm (b, DATA, est, g1, g3, ifault, 6, 3, 4, 5, phi, q1, resid, theta, v)
WRITE (30,60) theta
60 FORMAT (//'FINAL PARAMETER ESTIMATES = ', 4F9.6)
WRITE (30,70) phi
70 FORMAT (//'FINAL PHI = ', e13.7)
WRITE (30,80) q1
80 FORMAT (//'FINAL Q = ', 4E16.7)
WRITE (30,90)
90 FORMAT (//'ESTIMATED TRUE VALUES OF MEASUREMENTS')
WRITE (30,100) ((est(i,j),j=1,5),i=1,6)
100 FORMAT (5F9.4)
WRITE (30,110)
110 FORMAT (//'RESIDUALS')
WRITE (30,100) ((resid(i,j),j=1,5),i=1,6)
WRITE (30,120)
120 FORMAT (//'EXPECTED INFORMATION MATRIX')
WRITE (30,130) g1
130 FORMAT (4F9.4)
WRITE (30,140)
140 FORMAT (//'INVERSE OF EXPECTED INFORMATION MATRIX')
WRITE (30,130) g3
WRITE (30,150)
150 FORMAT (//'FAULT STATUS')
WRITE (30,160) ifault
160 FORMAT (2I5)
STOP
END PROGRAM ex1



SUBROUTINE bf (b, f, theta, xi)
IMPLICIT NONE
INTEGER, PARAMETER  :: dp = SELECTED_REAL_KIND(12, 60)

REAL (dp), INTENT(OUT)  :: b(:,:)
REAL (dp), INTENT(OUT)  :: f(:)
REAL (dp), INTENT(IN)   :: theta(:)
REAL (dp), INTENT(IN)   :: xi(:)

f(1)=theta(1)**2 + theta(2)*xi(1) + theta(3)*xi(2)**2 - xi(3)
f(2)=theta(2)**2 + (theta(3)*xi(1))**2 + theta(4)**3*xi(3)**2 - xi(4)
f(3)=theta(3)**2 + (theta(1)*xi(2))**2 - xi(5)
b(1,1)=theta(2)
b(1,2)=2.e0*theta(3)*xi(2)
b(1,3)=-1.e0
b(1,4)=0.e0
b(1,5)=0.e0
b(2,1)=2.e0*theta(3)**2*xi(1)
b(2,2)=0.e0
b(2,3)=2.e0*theta(4)**3*xi(3)
b(2,4)=-1.e0
b(2,5)=0.e0
b(3,1)=0.e0
b(3,2)=2.e0*theta(1)**2*xi(2)
b(3,3)=0.e0
b(3,4)=0.e0
b(3,5)=-1.e0
RETURN
END SUBROUTINE bf



SUBROUTINE zed (b, f, theta, xi, z)
IMPLICIT NONE
INTEGER, PARAMETER  :: dp = SELECTED_REAL_KIND(12, 60)

REAL (dp), INTENT(IN)   :: b(:,:)
REAL (dp), INTENT(IN)   :: f(:)
REAL (dp), INTENT(IN)   :: theta(:)
REAL (dp), INTENT(IN)   :: xi(:)
REAL (dp), INTENT(OUT)  :: z(:,:)

z(1,1)=2.e0*theta(1)
z(1,2)=xi(1)
z(1,3)=xi(2)**2
z(1,4)=0.e0
z(2,1)=0.e0
z(2,2)=2.e0*theta(2)
z(2,3)=2.e0*theta(3)*xi(1)**2
z(2,4)=3.e0*(theta(4)*xi(3))**2
z(3,1)=2.e0*theta(1)*xi(2)**2
z(3,2)=0.e0
z(3,3)=2.e0*theta(3)
z(3,4)=0.e0
RETURN
END SUBROUTINE zed
